@@ -8,6 +8,7 @@ from torch_dreams.auto_image_param import auto_image_param
 from torch_dreams.model_bunch import ModelBunch
 import numpy as np
 import torch
+import os 
 
     
 def make_custom_func(layer_number = 0, channel_number= 0): 
@@ -29,11 +30,14 @@ class test(unittest.TestCase):
             iters = 5
         )
 
+        image_param.save(filename = 'test_single_model.jpg')
+
+        self.assertTrue(os.path.exists('test_single_model.jpg'))
         self.assertTrue(isinstance(image_param, auto_image_param), 'should be an instance of auto_image_param')
         self.assertTrue(isinstance(image_param.__array__(), np.ndarray))
-        self.assertTrue(isinstance(image_param.to_hwc_numpy(), np.ndarray), 'should be a numpy.ndarray')
         self.assertTrue(isinstance(image_param.to_hwc_tensor(), torch.Tensor), 'should be a torch.Tensor')
         self.assertTrue(isinstance(image_param.to_chw_tensor(), torch.Tensor), 'should be a torch.Tensor')
+        os.remove('test_single_model.jpg')
 
     def  test_single_model_custom_func(self):
         model = models.inception_v3(pretrained=True)
@@ -46,11 +50,14 @@ class test(unittest.TestCase):
             custom_func= make_custom_func(layer_number= 0, channel_number= 10)
         )
 
+        image_param.save(filename = 'test_single_model_custom_func.jpg')
+        
+        self.assertTrue(os.path.exists('test_single_model_custom_func.jpg'))
         self.assertTrue(isinstance(image_param, auto_image_param), 'should be an instance of auto_image_param')
         self.assertTrue(isinstance(image_param.__array__(), np.ndarray))
-        self.assertTrue(isinstance(image_param.to_hwc_numpy(), np.ndarray), 'should be a numpy.ndarray')
         self.assertTrue(isinstance(image_param.to_hwc_tensor(), torch.Tensor), 'should be a torch.Tensor')
         self.assertTrue(isinstance(image_param.to_chw_tensor(), torch.Tensor), 'should be a torch.Tensor')
+        os.remove('test_single_model_custom_func.jpg')
 
     def test_multiple_models_custom_func(self):
 
@@ -81,12 +88,15 @@ class test(unittest.TestCase):
             iters= 5
         )
 
+        image_param.save(filename = 'test_multiple_models_custom_func.jpg')
+
+        self.assertTrue(os.path.exists('test_multiple_models_custom_func.jpg'))
         self.assertTrue(isinstance(image_param, auto_image_param), 'should be an instance of auto_image_param')
         self.assertTrue(isinstance(image_param.__array__(), np.ndarray))
-        self.assertTrue(isinstance(image_param.to_hwc_numpy(), np.ndarray), 'should be a numpy.ndarray')
         self.assertTrue(isinstance(image_param.to_hwc_tensor(), torch.Tensor), 'should be a torch.Tensor')
         self.assertTrue(isinstance(image_param.to_chw_tensor(), torch.Tensor), 'should be a torch.Tensor')
 
+        os.remove('test_multiple_models_custom_func.jpg')
 if __name__ == '__main__':
 
     unittest.main()
